==> web-0.2.20.jar: burningswell/web/actions_test.clj <==
(ns burningswell.web.actions-test
  (:require [burningswell.web.actions :as actions]
            [burningswell.db.spots :refer [mundaka]]
            [burningswell.web.getter.countries :as countries]
            [burningswell.web.getter.regions :as regions]
            [burningswell.web.getter.route :as route]
            [burningswell.web.getter.spots :as spots]
            [burningswell.web.test :refer :all]
            [clojure.core.async :refer [<!!]]
            [clojure.test :refer :all]
            [coolant.core :as coolant]))

(defn evaluate [system getter]
  (coolant/evaluate (:coolant system) getter))

(deftest test-initial-route
  (with-headless-system [system env]
    (is (= (evaluate system route/current) {:name :root}))))

(deftest test-change-route-signup
  (with-headless-system [system env]
    (actions/change-route system {:name :signup})
    (is (= (evaluate system route/current) {:name :signup}))))

(deftest test-change-route-signin
  (with-headless-system [system env]
    (actions/change-route system {:name :signin})
    (is (= (evaluate system route/current) {:name :signin}))))

(deftest test-change-route-countries
  (with-headless-system [system env]
    (<!! (actions/change-route system {:name :countries}))
    (is (= (evaluate system route/current) {:name :countries}))
    (is (= (map :name (evaluate system countries/country-list))
           ["Indonesia" "Portugal" "Spain" "United States"]))))

(deftest test-change-route-regions
  (with-headless-system [system env]
    (<!! (actions/change-route system {:name :regions}))
    (is (= (evaluate system route/current) {:name :regions}))
    (is (= (map :name (evaluate system regions/region-list))
           ["Bali" "Hawaii" "Lisboa" "País Vasco"]))))

(deftest test-change-route-spots
  (with-headless-system [system env]
    (let [spot (mundaka (-> system :api :db))]
      (actions/change-current-location system (:location spot))
      (<!! (actions/change-route system {:name :spots}))
      (is (= (evaluate system route/current) {:name :spots}))
      (is (= (map :name (evaluate system spots/spot-list))
             ["Mundaka"
              "Meñakoz"
              "São Lorenço"
              "Coxos"
              "Ribeira D'ilhas"
              "Crazy Left"
              "Pontina"
              "Backdoor"
              "The Reef"
              "Praia do Norte"
              "Praia do Peixe"
              "Furnas"
              "Foz do Lizandro"
              "São Julião"
              "Costa da Caparica"
              "Praia do Castello"])))))

==> web-0.2.28.jar: burningswell/web/actions_test.clj <==
(ns burningswell.web.actions-test
  (:require [burningswell.db.spots :refer [mundaka]]
            [burningswell.web.getter.countries :as countries]
            [burningswell.web.getter.regions :as regions]
            [burningswell.web.getter.route :as route]
            [burningswell.web.getter.spots :as spots]
            [burningswell.web.test :refer :all]
            [burningswell.web.system.core :as system]
            [clojure.core.async :refer [<!!]]
            [clojure.test :refer :all]
            [coolant.core :as coolant]))

(defn evaluate [system getter]
  (system/evaluate system getter))

(deftest test-initial-route
  (with-headless-system [system env]
    (is (= (evaluate system route/current) {:name :root}))))

(deftest test-change-route-signup
  (with-headless-system [system env]
    (system/change-route system {:name :signup})
    (is (= (evaluate system route/current) {:name :signup}))))

(deftest test-change-route-signin
  (with-headless-system [system env]
    (system/change-route system {:name :signin})
    (is (= (evaluate system route/current) {:name :signin}))))

(deftest test-change-route-countries
  (with-headless-system [system env]
    (<!! (system/change-route system {:name :countries}))
    (is (= (evaluate system route/current) {:name :countries}))
    (is (= (map :name (evaluate system countries/country-list))
           ["Indonesia" "Portugal" "Spain" "United States"]))))

(deftest test-change-route-regions
  (with-headless-system [system env]
    (<!! (system/change-route system {:name :regions}))
    (is (= (evaluate system route/current) {:name :regions}))
    (is (= (map :name (evaluate system regions/region-list))
           ["Bali" "Hawaii" "Lisboa" "País Vasco"]))))

(deftest test-change-route-spots
  (with-headless-system [system env]
    (let [spot (mundaka (-> system :api :db))]
      (system/change-current-location system (:location spot))
      (<!! (system/change-route system {:name :spots}))
      (is (= (evaluate system route/current) {:name :spots}))
      (is (= (map :name (evaluate system spots/spot-list))
             ["Mundaka"
              "Meñakoz"
              "São Lorenço"
              "Coxos"
              "Ribeira D'ilhas"
              "Crazy Left"
              "Pontina"
              "Backdoor"
              "The Reef"
              "Praia do Norte"
              "Praia do Peixe"
              "Furnas"
              "Foz do Lizandro"
              "São Julião"
              "Costa da Caparica"
              "Praia do Castello"])))))
